@@ -10,11 +10,18 @@ class ListWithFields(list):
 
 
 class FilterBackend(filters.DjangoFilterBackend):
-
+    """
+    Our own FilterBackend that also tries to read order from the pagination class's ordering field
+    """
     def get_filterset_class(self, view, queryset=None):
 
+        # here we look for any pagination class and its ordering attribute. if there is none, we sort by id
+        __paginator_ordering = getattr(getattr(view, 'pagination_class', 0), 'ordering', ['id'])
+        if isinstance(__paginator_ordering, str):
+            __paginator_ordering = [__paginator_ordering]
+
         ordering_excluded_fields = getattr(view, 'filterset_ordering_exclude', [])
-        ordering_default = getattr(view, 'filterset_ordering_default', ['id'])
+        ordering_default = getattr(view, 'filterset_ordering_default', __paginator_ordering)
 
         class MyOrderingFilter(filters.OrderingFilter):
             def get_ordering(self, value):
